@@ -1,3 +1,5 @@
+import json.decoder
+
 import requests
 import pkg_resources
 from distutils.version import StrictVersion
@@ -15,8 +17,15 @@ def version_check():
                     "is available, please upgrade.".format(
                 current_pkg_version, latest_pkg_version))
             print('--------')
-    except:  # TODO(abidlabs): don't catch all exceptions
-        pass
+
+    except pkg_resources.DistributionNotFound:
+        raise RuntimeError("gradio is not setup or installed properly. Unable to get version info.")
+    except json.decoder.JSONDecodeError:
+        raise RuntimeWarning("Unable to parse version details from package URL.")
+    except KeyError:
+        raise RuntimeWarning("Package URL does not contain version info.")
+    except ConnectionError:
+        raise RuntimeWarning("Unable to connect with package URL to collect version info.")
 
 
 def error_analytics(type):
